Plover Stenograph USB
=====================

Use Stenograph Diamanté and Luminex machines on Plover. The plugin may not work with other machines. If it does, please let me know.

Special thanks to Keith McCready for his guidance and support.
